@@ -30,7 +30,7 @@ ELFINDER_CONNECTOR_OPTION_SETS = {
     #the default keywords demonstrates all possible configuration options
     #it allowes all file types, except from hidden files
     'default' : {
-        'debug' : False,
+        'debug' : False, #optionally set debug to True for additional debug messages
         'roots' : [ 
             #{
             #    'driver' : ElfinderVolumeLocalFileSystem,
@@ -39,7 +39,7 @@ ELFINDER_CONNECTOR_OPTION_SETS = {
             {
                 'id' : 'lff',
                 'driver' : ElfinderVolumeLocalFileSystem,
-                'path' : join(settings.MEDIA_ROOT, 'files'),
+                'path' : join(settings.MEDIA_ROOT, u'files'),
                 'alias' : 'Elfinder files',
                 #open this path on initial request instead of root path
                 #'startPath' : '',
@@ -131,11 +131,12 @@ ELFINDER_CONNECTOR_OPTION_SETS = {
     },
     #option set to only allow image files
     'image' : {
+        'debug' : False,
         'roots' : [
             {
                 'id' : 'lffim',
                 'driver' : ElfinderVolumeLocalFileSystem,
-                'path' : join(settings.MEDIA_ROOT, 'images'),
+                'path' : join(settings.MEDIA_ROOT, u'images'),
                 'alias' : 'Elfinder images',
                 'URL' : '%simages/' % settings.MEDIA_URL,
                 'onlyMimes' : ['image',],
@@ -158,4 +159,4 @@ ELFINDER_CONNECTOR_OPTION_SETS = {
     }
 }
 
-ELFINDER_CONNECTOR_OPTION_SETS.update(getattr(settings, 'ELFINDER_CONNECTOR_OPTION_SETS', {}))
\ No newline at end of file
+ELFINDER_CONNECTOR_OPTION_SETS.update(getattr(settings, 'ELFINDER_CONNECTOR_OPTION_SETS', {}))
