@@ -191,7 +191,7 @@ class ElfinderVolumeDriver(object):
         else:
             raise Exception(_('No volume id found'))
         
-        self._root = self._normpath(self._options['path'])
+        self._root = self._normpath(unicode(self._options['path']))
         self._separator = self._options['separator'] if 'separator' in self._options else os.sep
 
         #default file attribute
@@ -284,13 +284,13 @@ class ElfinderVolumeDriver(object):
             isdir = os.path.isdir(self._quarantine)
 
         if not self._options['quarantine'] or (isdir and not os.access(self._quarantine, os.W_OK)):
-            self._archivers['extract'] = []
+            self._archivers['extract'] = {}
             self._options['disabled'].append('extract')
         elif self._options['quarantine'] and not isdir:
             try:
                 os.mkdir(self._quarantine)
             except os.error:
-                self._archivers['extract'] = []
+                self._archivers['extract'] = {}
                 self._options['disabled'].append('extract')
         
         self._configure()
@@ -354,8 +354,8 @@ class ElfinderVolumeDriver(object):
         contains the following keys:
         
             :path:    the path to the root as it will be displayed to the end user
-            :url:    the url of file provided in the ``hash_`` argument
-            :rootUrl:    the root volume url
+            :url:    the root volume url 
+            :pathUrl:   url of the path provided in the ``hash_`` argument
             :tmbUrl:    the root thumbnail url
             :disabled:    a list of the disabled commands
             :separator:    the path separator for this volume
@@ -366,8 +366,9 @@ class ElfinderVolumeDriver(object):
         path = self.decode(hash_)
         return {
             'path' : self._path(self.decode(hash_)),
-            'url' : '%s%s' % (self._options['URL'], self._relpath(path).replace(self._options['separator'], '/')),
-            'rootUrl' : self._options['URL'],
+            'url' : self._options['URL'],
+            #this custom attribute (not part of the original response) is used to return the hash url
+            'pathUrl' : '%s%s' % (self._options['URL'], self._relpath(path).replace(self._options['separator'], '/')),
             'tmbUrl' : self._options['tmbURL'],
             'disabled' : self._options['disabled'],
             'separator' : self._separator,
@@ -1088,6 +1089,7 @@ class ElfinderVolumeDriver(object):
             hash_ = self._crypt(p)
             #hash is used as id in HTML that means it must contain vaild chars
             #make base64 html safe and append prefix in begining
+            hash_ = hash_.encode('utf-8') # unicode filename support
             hash_ = b64encode(hash_).translate(maketrans('+/=', '-_.'))
 
             #remove dots '.' at the end (used to be '=' in base64, before the translation)
@@ -1108,6 +1110,7 @@ class ElfinderVolumeDriver(object):
             #put cut = at the end
             h += "=" * ((4 - len(h) % 4) % 4)
             h = b64decode(h)
+            h = h.decode('utf-8') # unicode filename support
 
             path = self._uncrypt(h) 
             #append ROOT to path after it was cut in encode
@@ -1179,7 +1182,10 @@ class ElfinderVolumeDriver(object):
                     if not 'tmb' in stat and self._can_create_tmb(path, stat):
                         stat['tmb'] = self._get_tmb(stat['target'] if 'target' in stat else path, stat)
                     if not 'dim' in stat and stat['mime'].startswith('image'):
-                        stat['dim'] = self._dimensions(path)
+                        try:
+                            stat['dim'] = self._dimensions(path)
+                        except NotAnImageError:
+                            stat['dim'] = _('Unknown')
             
             if 'alias' in stat and stat['alias'] and 'target' in stat and stat['target']:
                 stat['thash'] = self.encode(stat['target'])
@@ -1405,6 +1411,7 @@ class ElfinderVolumeDriver(object):
             raise NamedError(ElfinderErrorMessages.ERROR_MOVE, self._path(src))
         
         self._clear_cached_dir(self._dirname(src))
+        self._clear_cached_stat(src)
         self._clear_cached_dir(dst)
         self._removed.append(stat)
         
@@ -2120,4 +2127,4 @@ class ElfinderVolumeDriver(object):
             **Not implemented**, each driver must provide its own
             imlementation.
         """
-        raise NotImplementedError
\ No newline at end of file
+        raise NotImplementedError
